<?php
/**
 * 用SyntaxHighlighter实现代码高亮
 * @package FHilight
 * @author df
 * @version 1.0.0
 * @link http://www.df-blog.cn
 * @license http://creativecommons.org/licenses/by-nc-sa/2.5/
 */


class FHilight_Plugin implements Typecho_Plugin_Interface
{
    /**
     * 激活插件方法,如果激活失败,直接抛出异常
     * 
     * @access public
     * @return void
     * @throws Typecho_Plugin_Exception
     */
    public static function activate()
    {
        Typecho_Plugin::factory('Widget_Abstract_Contents')->filter = array('FHilight_Plugin', 'render');
		Typecho_Plugin::factory('Widget_Archive')->header = array('FHilight_Plugin', 'Call_Back');
    }
    
    /**
     * 禁用插件方法,如果禁用失败,直接抛出异常
     * 
     * @static
     * @access public
     * @return void
     * @throws Typecho_Plugin_Exception
     */
    public static function deactivate(){}
    
    /**
     * 获取插件配置面板
     * 
     * @access public
     * @param Typecho_Widget_Helper_Form $form 配置面板
     * @return void
     */
    public static function config(Typecho_Widget_Helper_Form $form){
		$sect= new Typecho_Widget_Helper_Form_Element_Select('sect',array('Default','Django','FadeToGrey','Emacs','Midnight','RDark'),0,_t('代码样式'));
		$form->addInput($sect);
		$filters = new Typecho_Widget_Helper_Form_Element_Checkbox('filters', 
        array('AS3'=>'AS3','Bash'=>'Bash','Cpp'=>'Cpp,C,C++','CSharp'=>'CSharp,C#','Css'=>'Css','Delphi'=>'Delphi','Diff'=>'Diff','Groovy'=>'Groovy','Java'=>'Java',
		'JavaFX'=>'JavaFX','JScript'=>'JScript','Perl'=>'Perl','Php'=>'Php','Plain'=>'Plain','PowerShell'=>'PowerShell','Python'=>'Python','Ruby'=>'Ruby',
		'Scala'=>'Scala','Sql'=>'Sql','Vb'=>'Vb','Xml'=>'Xml'),array('Php', 'JScript','Python','Cpp' ,'Vb','CSS','Xml'), '语言支持');
        $form->addInput($filters->multiMode());	
	}
    
    /**
     * 个人用户的配置面板
     * 
     * @access public
     * @param Typecho_Widget_Helper_Form $form
     * @return void
     */
    public static function personalConfig(Typecho_Widget_Helper_Form $form){}    
    
    /**
     * 插件实现方法
     * 
     * @access public
     * @return void
     */
    public static function render($value, $widget, $lastResult)
    {
        $value = empty($lastResult) ? $value : $lastResult;
        if ($widget instanceof Widget_Archive) {
            $value['text'] = preg_replace_callback("/\[code=(.[a-zA-Z]*)([0-9]*)\](.*?)\[\/code\]/is", array('FHilight_Plugin', 'parseCallback'), $value['text']);
        }
        
        return $value;      
    }
	 public static function parseCallback($matches)
    {		
		return '<pre class="brush:'.$matches[1].'; first-line: '.$matches[2].';">'.$matches[3].'</pre>';
	}

	public static function Call_Back($headlink)
    {
		$Options=Typecho_Widget::widget('Widget_Options');
		$FHiLight_ul=$Options->pluginUrl .'/FHilight/';
		$Css_list=array('Default','Django','FadeToGrey','Emacs','Midnight','RDark');
		$FHiLight_css = 'shTheme' . $Css_list[$Options->plugin('FHilight')->sect] . '.css';
	    $Prg_List=$Options->plugin('FHilight')->filters;
		$headlink='<link type="text/css" rel="stylesheet" href="'.$FHiLight_ul.'shCore.css"/>
	<link type="text/css" rel="stylesheet" href="'.$FHiLight_ul.$FHiLight_css.'"/>
	<script type="text/javascript" src="'.$FHiLight_ul.'shCore.js"></script>';    
		foreach($Prg_List as $item){
			$headlink.='<script type="text/javascript" src="'.$FHiLight_ul.'shBrush'.$item.'.js"></script>';
		}
		echo $headlink.'<script type="text/javascript">
		SyntaxHighlighter.config.clipboardSwf = "'.$FHiLight_ul.'clipboard.swf";
		SyntaxHighlighter.config.bloggerMode = true;		
		SyntaxHighlighter.all();
		</script>';
    }
}
